@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 
 use base 'Data::Storage::DBI';
@@ -67,54 +67,42 @@ Data::Storage::DBI::SQLite - generic abstract storage mechanism
 None yet. This is an early release; fully functional, but undocumented. The
 next release will have more documentation.
 
+=head1 METHODS
+
+=over 4
+
+
+
+=back
+
 Data::Storage::DBI::SQLite inherits from L<Data::Storage::DBI>.
 
 The superclass L<Data::Storage::DBI> defines these methods and functions:
 
-    AutoCommit(), AutoCommit_clear(), DEFAULTS(), HandleError(),
-    HandleError_clear(), LongReadLen(), LongReadLen_clear(), PrintError(),
-    PrintError_clear(), RaiseError(), RaiseError_clear(), SQL_ALL_TYPES(),
-    SQL_ARRAY(), SQL_ARRAY_LOCATOR(), SQL_BIGINT(), SQL_BINARY(),
-    SQL_BIT(), SQL_BLOB(), SQL_BLOB_LOCATOR(), SQL_BOOLEAN(), SQL_CHAR(),
-    SQL_CLOB(), SQL_CLOB_LOCATOR(), SQL_DATE(), SQL_DATETIME(),
-    SQL_DECIMAL(), SQL_DOUBLE(), SQL_FLOAT(), SQL_GUID(), SQL_INTEGER(),
-    SQL_INTERVAL(), SQL_INTERVAL_DAY(), SQL_INTERVAL_DAY_TO_HOUR(),
-    SQL_INTERVAL_DAY_TO_MINUTE(), SQL_INTERVAL_DAY_TO_SECOND(),
-    SQL_INTERVAL_HOUR(), SQL_INTERVAL_HOUR_TO_MINUTE(),
-    SQL_INTERVAL_HOUR_TO_SECOND(), SQL_INTERVAL_MINUTE(),
-    SQL_INTERVAL_MINUTE_TO_SECOND(), SQL_INTERVAL_MONTH(),
-    SQL_INTERVAL_SECOND(), SQL_INTERVAL_YEAR(),
-    SQL_INTERVAL_YEAR_TO_MONTH(), SQL_LONGVARBINARY(), SQL_LONGVARCHAR(),
-    SQL_MULTISET(), SQL_MULTISET_LOCATOR(), SQL_NUMERIC(), SQL_REAL(),
-    SQL_REF(), SQL_ROW(), SQL_SMALLINT(), SQL_TIME(), SQL_TIMESTAMP(),
-    SQL_TINYINT(), SQL_TYPE_DATE(), SQL_TYPE_TIME(), SQL_TYPE_TIMESTAMP(),
-    SQL_TYPE_TIMESTAMP_WITH_TIMEZONE(), SQL_TYPE_TIME_WITH_TIMEZONE(),
-    SQL_UDT(), SQL_UDT_LOCATOR(), SQL_UNKNOWN_TYPE(), SQL_VARBINARY(),
-    SQL_VARCHAR(), SQL_WCHAR(), SQL_WLONGVARCHAR(), SQL_WVARCHAR(),
-    assert_defined(), clear_AutoCommit(), clear_HandleError(),
-    clear_LongReadLen(), clear_PrintError(), clear_RaiseError(),
-    clear_dbh(), clear_dbhost(), clear_dbname(), clear_dbpass(),
-    clear_dbuser(), clear_port(), clear_schema_prefix(), commit(),
-    connect(), connect_string_dbi_id(), dbh(), dbh_clear(), dbhost(),
-    dbhost_clear(), dbname(), dbname_clear(), dbpass(), dbpass_clear(),
-    dbuser(), dbuser_clear(), disconnect(), except(), finally(),
-    get_connect_options(), is_connected(), lazy_connect(), otherwise(),
-    port(), port_clear(), prepare(), rewrite_query(),
+    AutoCommit(), AutoCommit_clear(), HandleError(), HandleError_clear(),
+    LongReadLen(), LongReadLen_clear(), PrintError(), PrintError_clear(),
+    RaiseError(), RaiseError_clear(), clear_AutoCommit(),
+    clear_HandleError(), clear_LongReadLen(), clear_PrintError(),
+    clear_RaiseError(), clear_dbh(), clear_dbhost(), clear_dbname(),
+    clear_dbpass(), clear_dbuser(), clear_port(), clear_schema_prefix(),
+    commit(), connect(), dbh(), dbh_clear(), dbhost(), dbhost_clear(),
+    dbname(), dbname_clear(), dbpass(), dbpass_clear(), dbuser(),
+    dbuser_clear(), disconnect(), get_connect_options(), is_connected(),
+    lazy_connect(), port(), port_clear(), prepare(), rewrite_query(),
     rewrite_query_for_dbd(), rollback(), schema_prefix(),
-    schema_prefix_clear(), signature(), try(), with()
+    schema_prefix_clear(), signature()
 
 The superclass L<Data::Storage> defines these methods and functions:
 
     new(), clear_log(), clear_rollback_mode(), create(), id(),
-    initialize_data(), is_abstract(), log(), log_clear(), rollback_mode(),
+    initialize_data(), log(), log_clear(), rollback_mode(),
     rollback_mode_clear(), rollback_mode_set(), set_rollback_mode(),
     setup()
 
 The superclass L<Class::Accessor::Complex> defines these methods and
 functions:
 
-    carp(), cluck(), croak(), flatten(), mk_abstract_accessors(),
-    mk_array_accessors(), mk_boolean_accessors(),
+    mk_abstract_accessors(), mk_array_accessors(), mk_boolean_accessors(),
     mk_class_array_accessors(), mk_class_hash_accessors(),
     mk_class_scalar_accessors(), mk_concat_accessors(),
     mk_forward_accessors(), mk_hash_accessors(), mk_integer_accessors(),
@@ -132,15 +120,37 @@ The superclass L<Class::Accessor> defines these methods and functions:
 The superclass L<Class::Accessor::Installer> defines these methods and
 functions:
 
-    install_accessor(), subname()
+    install_accessor()
 
-=head1 METHODS
+The superclass L<Class::Accessor::Constructor> defines these methods and
+functions:
 
-=over 4
+    _make_constructor(), mk_constructor(), mk_constructor_with_dirty(),
+    mk_singleton_constructor()
 
+The superclass L<Data::Inherited> defines these methods and functions:
 
+    every_hash(), every_list(), flush_every_cache_by_key()
 
-=back
+The superclass L<Class::Accessor::Constructor::Base> defines these methods
+and functions:
+
+    STORE(), clear_dirty(), clear_hygienic(), clear_unhygienic(),
+    contains_hygienic(), contains_unhygienic(), delete_hygienic(),
+    delete_unhygienic(), dirty(), dirty_clear(), dirty_set(),
+    elements_hygienic(), elements_unhygienic(), hygienic(),
+    hygienic_clear(), hygienic_contains(), hygienic_delete(),
+    hygienic_elements(), hygienic_insert(), hygienic_is_empty(),
+    hygienic_size(), insert_hygienic(), insert_unhygienic(),
+    is_empty_hygienic(), is_empty_unhygienic(), set_dirty(),
+    size_hygienic(), size_unhygienic(), unhygienic(), unhygienic_clear(),
+    unhygienic_contains(), unhygienic_delete(), unhygienic_elements(),
+    unhygienic_insert(), unhygienic_is_empty(), unhygienic_size()
+
+The superclass L<Tie::StdHash> defines these methods and functions:
+
+    CLEAR(), DELETE(), EXISTS(), FETCH(), FIRSTKEY(), NEXTKEY(), SCALAR(),
+    TIEHASH()
 
 =head1 TAGS
 
@@ -149,7 +159,7 @@ please use the C<datastorage> tag.
 
 =head1 VERSION 
                    
-This document describes version 0.05 of L<Data::Storage::DBI::SQLite>.
+This document describes version 0.06 of L<Data::Storage::DBI::SQLite>.
 
 =head1 BUGS AND LIMITATIONS
 
@@ -175,7 +185,7 @@ Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2007 by Marcel GrE<uuml>nauer
+Copyright 2004-2008 by Marcel GrE<uuml>nauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
